<?php

/**
 * @file
 * Contains database operations.
 */

/**
 * Insert settings.
 */
function field_extra_settings_add($params) {
  drupal_write_record('field_extra_settings', $params);

}

/**
 * Update settings.
 */
function field_extra_settings_update($params) {
  unset($params['id']);

  $query = db_update('field_extra_settings');
  $query->fields($params);
  unset($params['settings']);

  foreach ($params as $field_name => $param) {
    $query->condition($field_name, $param);
  }

  return $query->execute();
}

/**
 * Load settings.
 */
function field_extra_settings_load($params, $data = FALSE) {
  unset($params['settings']);

  $query = db_select('field_extra_settings', 'fes');
  $query->fields('fes');

  foreach ($params as $field_name => $param) {
    $query->condition($field_name, $param);
  }

  $result = $query->execute()->fetchAllAssoc('entity_id');

  return $data && $result ? unserialize(current($result)->settings) : $result;
}

/**
 * Helper function for prepare element load parameters.
 */
function field_extra_settings_prepare_load_params($element) {
  // On the view we have object, on the edit we have an entity.
  $element['#object'] = $element['#object'] ?? $element["#entity"];

  // We work only with paragraphs.
  if (!($element['#object'] instanceof stdClass) && !($element['#object'] instanceof ParagraphsItemEntity)) {
    return [];
  }

  $entity_type = $element['value']['#entity_type'] ?? $element['#entity_type'];
  $wrapper = entity_metadata_wrapper($entity_type, $element['#object']);

  return [
    'field_name' => $element['#field_name'],
    'bundle' => $element['#bundle'],
    'entity_type' => $entity_type,
    'entity_id' => $element['#object'] instanceof ParagraphsItemEntity ? $element['#object']->hostEntityId() : $wrapper->getIdentifier(),
  ];
}

