<?php

/**
 * @file
 * Contains data display functionality.
 */

/**
 * Implements hook_preprocess_field().
 */
function field_extra_settings_preprocess_field(&$variables, $hook) {
  $element = $variables['element'];

  // Check whether is active, for performance.
  if (!field_extra_settings_check_is_activated($element['#entity_type'], $element['#bundle'], $element['#field_name'])) {
    return;
  }

  if (!$params = field_extra_settings_prepare_load_params($element)) {
    return;
  }
  $load_settings = field_extra_settings_load($params, TRUE);

  if ($load_settings) {

    foreach ($load_settings[$element["#field_name"]] as $key => $item) {

      $classes = ['extra-class'];
      $item_val =& $variables["items"][$key];

      foreach ($item as $item_name => $css_class) {

        if (is_string($css_class)) {
          $classes[] = $css_class;
        }
      }

      if (!isset($item_val['#prefix'])) {
        $class = implode(' ', $classes);
        $item_val['#prefix'] = "<div class=\"$class\">";
        $item_val['#suffix'] = '</div>';
      }

      if (isset($item["image_representation_types"])) {
        $item_val['#image_style'] = $item["image_representation_types"];
      }
    }
  }
}

/**
 * Implements hook_entity_view().
 */
function field_extra_settings_entity_view($entity, $type, $view_mode, $langcode) {
  $wrapper = entity_metadata_wrapper($type, $entity);

  foreach ($entity->content as $field_name => $value) {

    // Check whether is active, for performance.
    if (!$wrapper->getBundle() || !field_extra_settings_check_is_activated($type, $wrapper->getBundle(), $field_name)) {
      continue;
    }

    $element = [
      '#field_name' => $field_name,
      '#entity_type' => $type,
      '#bundle' => $wrapper->getBundle(),
      '#object' => $entity,
    ];

    if (!$params = field_extra_settings_prepare_load_params($element)) {
      return;
    }

    $load_settings = field_extra_settings_load($params, TRUE)[$field_name];

    foreach ($entity->content[$field_name]['#items'] as $item_key => $item) {
      $visible = TRUE;
      $current_key = $load_settings[$item_key];

      // Hide by user role.
      if (!empty($current_key['restrict_access_by_role'])) {
        global $user;

        if (!array_intersect($user->roles, $current_key['restrict_access_by_role'])) {
          $visible = FALSE;
        }

        if (!array_filter($current_key['restrict_access_by_role'])) {
          $visible = TRUE;
        }
      }

      // Hide entire field.
      if (!empty($current_key['available_to_hide']) && $current_key['available_to_hide']) {
        $visible = FALSE;
      }

      // Hide field from display.
      if (!$visible) {
        $entity->content[$field_name][$item_key] = [];
      }
    }
  }
}
